@@ -97,6 +97,22 @@ function viewDistributionMenu() {
     	}
     );
     
+    register("OX_Object_Distributionlist_EditName", function() {
+        distruBigGrid.updateSelected(function(i, data) {
+            if (data.edit) {
+                setTimeout( function() { data.edit.display_name(); }, 0);
+            }
+        });
+    });
+    
+    register("OX_Object_Distributionlist_EditEmail", function() {
+        distruBigGrid.updateSelected(function(i, data) {
+            if (data.edit) {
+                setTimeout( function() { data.edit.email(); }, 0);
+            }
+        });
+    });
+    
     register("OX_Object_Distributionlist_Delete", 
     	function() {
     		distruBigGrid.deleteIDs(distruBigGrid.selection.getSelected());
@@ -387,26 +403,41 @@ function distrFromAddressbookLive() {
 	distruBigGrid = new LiveGrid([
         { 
             text: _("Name"),
-            clear: LiveGrid.makeClear(""),
-            set: function(div, external) {
-                if (div.firstChild)
-                    div.firstChild.data = external.display_name;
-                else
-                    div.appendChild(document.createTextNode(external.display_name));
-            }
+            clear: function(div) { setter(div, {}, "display_name"); },
+            set: function(div, data) { setter(div, data, "display_name"); }
         },
         {
             text: _("E-Mail"),
-            clear: LiveGrid.makeClear(""),
-            set: function(div, external) {
-                if (div.firstChild)
-                    div.firstChild.data = external.email;
-                else
-                    div.appendChild(document.createTextNode(external.email));
-            }
+            clear: function(div) { setter(div, {}, "email"); },
+            set: function(div, data) { setter(div, data, "email"); }
         }
     ], selection);
-			
+    
+    function setter(div, data, field) {
+        var node = jQuery(div);
+        if (!node.data("LiveGridData")) node.dblclick(dblclick);
+        node.text(data[field]).data("LiveGridData", data);
+        if (data.external) {
+            if (!data.edit) data.edit = {};
+            data.edit[field] = edit;
+        }
+        function dblclick(e) {
+            if (!node.data("LiveGridData").external) return;
+            e.stopPropagation();
+            setTimeout(edit, 0); // Required due to the timeout in setFocus()
+        }                        // which is called by the LiveGrid.
+        function edit() { new inplaceEdit(div, node.text(), save).on(); }
+        function save(newValue) {
+            distruBigGrid.storage.localUpdate(
+                [distruBigGrid.storage.makeID(node.data("LiveGridData"))],
+                function(i, old) {
+                    old[field] = newValue;
+                    return old;
+                });
+            setBeforeUnload(true);
+        }
+    }
+    
 	distruBigGrid.emptylivegridtext = "";	
     // add livegrid header and content to dom node
     $("newDistrListLiveHeader").appendChild(distruBigGrid.getHeader());
@@ -414,8 +445,7 @@ function distrFromAddressbookLive() {
     distruBigGrid.enable(storage);
     
     // what to do when select a appointment
-	distruBigGrid.events.register("Selected", function(ids) {		
-		var count = distruBigGrid.selection.getSelected().length;		
+	distruBigGrid.events.register("Selected", function(count) {		
 		triggerEvent("SubSelected", count);
 	});
 	
@@ -679,31 +709,24 @@ function fillFields(data) {
  * Write all filled fields in DB
  * json.put -> contact_object
  */
-function writeNewContact() {
-	if($("display_name").value == "") {
-		triggerEvent("OX_New_Error", 4, _("Mandatory Field(s) missing!"));
-		$("display_name").className += " borderDefault border-color-error";
-		$("display_name").focus();
-		savePending = false;	
-	} else {		
-		contact_object.last_name = $('display_name').value;
-		contact_object.display_name = $('display_name').value;
-		contact_object.folder_id = clickedItemForSave;
-				
-		var tmpString = new Array;
-		contact_object.distribution_list = tmpString; //mark as Distribution List
-		getDistrForSave();
-		setModalBusy(true);
-		json.put(AjaxRoot + "/contacts?action=new" + 
-				"&session=" + corewindow.session + 
-				"&folder=" + clickedItemForSave , 
-				contact_object, null, function(idObj){
-				if(idObj) {	
-					newContactId = idObj.data.id;
-					finalFunction();
-				}
-			}, setModalBusy);
-	}
+function writeNewContact() {	
+	contact_object.last_name = $('display_name').value;
+	contact_object.display_name = $('display_name').value;
+	contact_object.folder_id = clickedItemForSave;
+			
+	var tmpString = new Array;
+	contact_object.distribution_list = tmpString; //mark as Distribution List
+	getDistrForSave();
+	setModalBusy(true);
+	json.put(AjaxRoot + "/contacts?action=new" + 
+			"&session=" + corewindow.session + 
+			"&folder=" + clickedItemForSave , 
+			contact_object, null, function(idObj){
+			if(idObj) {	
+				newContactId = idObj.data.id;
+				finalFunction();
+			}
+		}, setModalBusy);
 }
 
 
