@@ -415,7 +415,7 @@ function expectI18n(text) {
                         context = original.substring(0, pipe);
                         original = original.substring(pipe + 1);
                     }
-					text.nodeValue = dpgettext("", context, original);
+					text.nodeValue = String(dpgettext("", context, original));
 				}
 			}
 		}
@@ -1286,22 +1286,40 @@ var currencies = [
         ];
 
 // time-based greeting phrase
-var getGreetingPhrase  = function (time) {
-    // vars
-    var hour, phrase;
-    // now?
-    if (time === undefined) {
-        hour = new Date().getHours();
-    } else {
-        hour = new Date(time).getHours();
+function getGreetingPhrase() {
+    // phrase definitions
+    var periods = [5, 12, 18, 24]; // start of the next period
+    var phrases = [_("Hello"), _("Good morning"), _("Hello"), _("Good evening")];
+
+    // returns the phrase index for a timestamp
+    function getPeriod(t) {
+        var h = new Date(t).getUTCHours();
+        for (var i = 0; i < periods.length; i++) if (h < periods[i]) return i;
     }
-    // find proper phrase
-    if (hour >= 5 && hour <= 11) {
-        phrase = _("Good morning");
-    } else if (hour >= 18 && hour <= 23) {
-        phrase = _("Good evening");
-    } else {
-        phrase = _("Hello");
+    
+    var date, timeout;
+    var node = new I18nNode(function() { return phrases[this.period]; },
+                            { period: 0 });
+    
+    init();
+    function init() {
+        var t = now();
+        node.period = getPeriod(t) - 1; // will be incremented by next()
+        date = new Date(t);
+        next();
     }
-    return phrase;
-};
+    
+    function next() {
+        if (++node.period >= periods.length) node.period = 0;
+        node.update();
+        date.setUTCHours(periods[node.period], 0, 0, 0);
+        timeout = setTimeout(next, Math.max(0, date.getTime() - now()));
+    }
+    
+    register("TimeUpdated", function() {
+        clearTimeout(timeout);
+        init();
+    });
+            
+    return node.node;
+}
