@@ -382,9 +382,13 @@ function initMessageContent(loadblockedimages) {
 		
 		// get mail
 		var cont = function (daten) {
-            if (daten.objects[0]) {
+            var object = daten.objects[0];
+            if (object) {
+                if (!(object.flags & 32)) {
+                    OXMailMapping.setMailFlags("seen",[object]);
+                }
                 mailFetchTimestamp = daten.timestamp;
-                showMessage(daten.objects[0], message.folder_id);
+                showMessage(object, message.folder_id);
             }
         };
 
@@ -460,7 +464,7 @@ function drawMessage(message, folder) {
 	
 	var from = setAdressHeader("from", message["from"]);
 	if (from && message["headers"] && message["headers"]["Sender"] && 
-			message["from"] != message["headers"]["Sender"]) {
+	        new RegExp(message["headers"]["Sender"],"ig").test(refToMain.getAdressString(message["from"], false)) === false) {
     	from.insertBefore(newtext(format(_("%1$s on behalf of"), [ message["headers"]["Sender"] ]) + " "), 
     			from.firstChild);
 	}
@@ -743,6 +747,8 @@ function setMessageText(message) {
                                     "",
                                     function() {
                                         //deleteMails(message.folder_id, [ message ]);
+                                        //#. Status message will be shown when the confirmation status has been saved
+                                        //#. after clicking on any confirmation button in an itip mail
                                         ox.UINotifier.ok(_("Confirmation status has been saved."));
                                     });
                                     return false;
