@@ -277,15 +277,16 @@ var setMailHeaderLabel;
     // change the default selected fields checked
     // in the search menu depending on the folder
     function setSearch() {
+        var to = isStdFolder("sent") || isStdFolder("drafts");
         ox.widgets.searchField.active().searchMenu.setFields(
                 ["from", "to", "cc", "subject", "mailtext" ],
                 [ pgettext("who", "From"), _("To"), _("Cc"), _("Subject"),
                   _("Mailtext")],
-                { from: !isStdFolder("sent"), to: isStdFolder("sent"), cc: true, subject: true, mailtext: false }
+                { from: !to, to: to, cc: true, subject: true, mailtext: false }
         );
 
-        // change header description if the folder is sent or draft
-        jQuery(".received").text(isStdFolder("sent") ||  isStdFolder("drafts") ?
+        // change header description if the folder is sent
+        jQuery(".received").text(isStdFolder("sent") ?
                 _("Sent").toString() : _("Received").toString());
     }
 
@@ -408,8 +409,10 @@ var setMailHeaderLabel;
     /**
      * in folder 'Sent' and 'Drafts' we have to use other fields then the
      * default once. this function switch between these headers and sort parameter
-     * within the given livegrid. combinations are: folder sent and
-     * drafts -> 'To' and 'Reveived Date', otherwise 'From' and 'Sent Date'
+     * within the given livegrid. The combinations are:
+     * - sent: 'To' and 'Sent Date',
+     * - drafts: 'To' and 'Received Date',
+     * - otherwise 'From' and 'Received Date'.
      * @param grid - {LiveGrid} - the current livegrid
      */
     function switchGridHeaders(grid) {
@@ -417,22 +420,31 @@ var setMailHeaderLabel;
         //setMailHeaderLabel();
         view.grid.searchActive=false; // set search to inactive, not sure if
 
-        var sent = isStdFolder("sent") || isStdFolder("drafts");
-        if (sent == Boolean(grid.oldSent)) return;
-        grid.oldSent = sent;
-
-        if (sent) {
-            columnFromTo.text = _("To");
-            columnReceivedSent.text = _("Sent");
-            change("from", "to");
-            change("received_date", "sent_date");
-        } else {
-            columnFromTo.text = pgettext("who", "From");
-            columnReceivedSent.text = _("Received");
-            change("to", "from");
-            change("sent_date", "received_date");
+        var sent = isStdFolder("sent");
+        var to = sent || isStdFolder("drafts");
+        if (sent == Boolean(grid.oldSent) && to == Boolean(grid.oldTo)) return;
+        
+        if (to != Boolean(grid.oldTo)) {
+            grid.oldTo = to;
+            if (to) {
+                columnFromTo.text = _("To");
+                change("from", "to");
+            } else {
+                columnFromTo.text = pgettext("who", "From");
+                change("to", "from");
+            }
         }
-
+        if (sent != Boolean(grid.oldSent)) {
+            grid.oldSent = sent;
+            if (sent) {
+                columnReceivedSent.text = _("Sent");
+                change("received_date", "sent_date");
+            } else {
+                columnReceivedSent.text = _("Received");
+                change("sent_date", "received_date");
+            }
+        }
+        
         function change(oldCol, newCol) {
             if (sort_id == oldCol) sort_id = newCol;
             for (var i = 0; i < grid.columns.length; i++) {
@@ -944,9 +956,7 @@ var setMailHeaderLabel;
                 width: (IE && IE == "7" ? "15%" : "11em"),
                 set: function(div, content) {
                     var dateToShow = content["received_date"];
-                    if (isStdFolder("sent") || isStdFolder("drafts")) {
-                        dateToShow = content["sent_date"];
-                    }
+                    if (isStdFolder("sent")) dateToShow = content["sent_date"];
                     dateToShow = dateToShow ? formatDate(dateToShow, isToday(dateToShow) ? "time" : "datetime") : "";
                     if (!div.firstChild) {
                         div.appendChild(div.ownerDocument.createTextNode(dateToShow));
@@ -1045,7 +1055,8 @@ var setMailHeaderLabel;
 
             // get table cells
             var tds = tmp.getElementsByTagName("td");
-            var sent = isStdFolder("sent") || isStdFolder("drafts");
+            var sent = isStdFolder("sent");
+            var to = sent || isStdFolder("drafts");
 
             // helper
             function setIcon(index, path, width, height) {
@@ -1065,7 +1076,7 @@ var setMailHeaderLabel;
             setIcon(0, "img/mail/" + getMailFlagImage(content["flags"]), 16, 16);
 
             // to / from
-            var aAddressToShow = content[sent ? "to" : "from"] || [];
+            var aAddressToShow = content[to ? "to" : "from"] || [];
             var addressString = getAdressString(aAddressToShow, true);
             // remove quoting marks
             addressString = addressString.replace(/(^"|"$)/g, '');
@@ -1407,7 +1418,7 @@ var setMailHeaderLabel;
                     break;
                 case "received_date" :
                     dateToShow = newField;
-                    if (isStdFolder("sent") || isStdFolder("drafts")) {
+                    if (isStdFolder("sent")) {
                         dateToShow = message["sent_date"];
                     }
                     if (dateToShow) {
@@ -1468,7 +1479,7 @@ var setMailHeaderLabel;
         
         // append or clear 'on behalf of' string if sender != from
         if (message["headers"] && message["headers"]["Sender"] &&
-                message["from"] != message["headers"]["Sender"]) {
+                new RegExp(message["headers"]["Sender"],"ig").test(getAdressString(message["from"], false)) === false) {
             var text = newtext(format(_("%1$s on behalf of"), [ message["headers"]["Sender"] ]) + " ");
             jQuery("#mail\\." + view.name + "\\.detail\\.header\\.from span").
                 before(newnode("span", 0, { className: "sender" }, [ text.cloneNode(true) ]));
@@ -1711,6 +1722,8 @@ var setMailHeaderLabel;
                                             "",
                                             function() {
                                                 //deleteMails(message.folder_id, [ message ]);
+                                                //#. Status message will be shown when the confirmation status has been saved
+                                                //#. after clicking on any confirmation button in an itip mail
                                                 ox.UINotifier.ok(_("Confirmation status has been saved."));
                                             });
                                             return false;
@@ -2019,11 +2032,12 @@ var setMailHeaderLabel;
                        newitem(_("Read/Unread"), "flags_sort");
                        newitem(_("Flag"),        "color_label");
         menu.onShow = function() {
-            var sentFolder = isStdFolder("sent") || isStdFolder("drafts");
-            from.setVisible(!sentFolder);
-            to.setVisible(sentFolder);
-            sent.setVisible(sentFolder);
-            received.setVisible(!sentFolder);
+            var _sent = isStdFolder("sent");
+            var _to = _sent || isStdFolder("drafts");
+            from.setVisible(!_to);
+            to.setVisible(_to);
+            sent.setVisible(_sent);
+            received.setVisible(!_sent);
         };
 
         addDOMEvent($("mail.vsplit.sortType"), "mousedown", function() {
