@@ -213,7 +213,10 @@ split.init = function() {
                     rule.active = checkbox.checked;
                     ox.JSON.put(AjaxRoot +
                         "/mailfilter?action=update&session=" +
-                        session, rule, emptyFunction);
+                        session, rule, function() {
+                            ox.Configuration.info(
+                                _("Your settings have been saved."));
+                        });
                 });
         });
         return checkbox;
